==> tyrquake-0.45.tar.gz: tyrquake/include/wad.h <==
/*
Copyright (C) 1996-1997 Id Software, Inc.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef WAD_H
#define WAD_H

#include "qtypes.h"

//===============
//   TYPES
//===============

#define	CMP_NONE		0
#define	CMP_LZSS		1

#define	TYP_NONE		0
#define	TYP_LABEL		1

#define	TYP_LUMPY		64	// 64 + grab command number
#define	TYP_PALETTE		64
#define	TYP_QTEX		65
#define	TYP_QPIC		66
#define	TYP_SOUND		67
#define	TYP_MIPTEX		68

typedef struct {
    int width, height;
    byte data[4];		// variably sized
} qpic_t;



typedef struct {
    char identification[4];	// should be WAD2 or 2DAW
    int numlumps;
    int infotableofs;
} wadinfo_t;

typedef struct {
    int filepos;
    int disksize;
    int size;			// uncompressed
    char type;
    char compression;
    char pad1, pad2;
    char name[16];		// must be null terminated
} lumpinfo_t;

extern int wad_numlumps;
extern lumpinfo_t *wad_lumps;
extern byte *wad_base;

void W_LoadWadFile(const char *filename);
void W_CleanupName(const char *in, char *out);
lumpinfo_t *W_GetLumpinfo(const char *name);
void *W_GetLumpName(const char *name);
void *W_GetLumpNum(int num);

void SwapPic(qpic_t *pic);

#endif /* WAD_H */

==> tyrquake-0.61_20140630.tar.gz: tyrquake/include/wad.h <==
/*
Copyright (C) 1996-1997 Id Software, Inc.

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef WAD_H
#define WAD_H

#include "qtypes.h"

//===============
//   TYPES
//===============

#define	CMP_NONE		0
#define	CMP_LZSS		1

#define	TYP_NONE		0
#define	TYP_LABEL		1

#define	TYP_LUMPY		64	// 64 + grab command number
#define	TYP_PALETTE		64
#define	TYP_QTEX		65
#define	TYP_QPIC		66
#define	TYP_SOUND		67
#define	TYP_MIPTEX		68

typedef struct {
    int width, height;
    byte data[];
} dpic8_t;

typedef struct {
    char identification[4];	// should be WAD2 or 2DAW
    int numlumps;
    int infotableofs;
} wadinfo_t;

#define LUMP_NAMELEN 16
typedef struct {
    int filepos;
    int disksize;
    int size;			// uncompressed
    char type;
    char compression;
    char pad1, pad2;
    char name[LUMP_NAMELEN];	// must be null terminated
} lumpinfo_t;

typedef struct {
    int numlumps;
    lumpinfo_t *lumps;
    byte *base;
} wad_t;

void W_LoadWadFile(wad_t *wad, const char *filename);
void W_CleanupName(const char *in, char *out);
lumpinfo_t *W_GetLumpinfo(wad_t *wad, const char *name);
void *W_GetLumpName(wad_t *wad, const char *name);
void *W_GetLumpNum(wad_t *wad, int num);

void SwapDPic(dpic8_t *dpic);

#endif /* WAD_H */
